	org $1001-2
	dw  $1001
	
DEBUG = 0
SOUND_DEBUG = 0
	
	dw nextln,0	; second word is line number
	db $9E,"4109",0
nextln	db 0,0

astack	= $08
xstack	= $09
ystack	= $0A
irq_a	= $13
irq_x	= $14
irq_y	= $15

MAX_BOB_COUNT = 19	; PAL = 19, NTSC = 10
bob_x_lookup_lo = $FB00
bob_x_lookup_hi = $FC00

bob_byte1	= $C0
bob_byte2	= $C1
bob_ptr1	= $C2
bob_ptr2	= $C4
bob_count	= $C6

timeline_ptr	= $D0
timeline_delay	= $D2

pos		= $E0
ptr		= $E2
ptr2		= $E4
letters_ptr 	= $E6
text_wipe_ptr1 	= $E8
text_wipe_ptr2 	= $EA

	include "!playerv.asm"

setptr	macro p,addr
	lda #addr & 255
	sta p
	lda #addr >> 8
	sta p+1
	endm

sbcw	macro addr,number
	lda addr
	sec
	sbc #number & 255
	sta addr
	lda addr+1
	sbc #number >> 8
	sta addr+1
	endm

adcw	macro addr,number
	if number < 256
	lda addr
	clc
	adc #number
	sta addr
	bcc *+4
	inc addr+1
	endif
	if number >= 256
	lda addr
	clc
	adc #number & 255
	sta addr
	lda addr+1
	adc #number >> 8
	sta addr+1
	endif
	endm
	
start
	sei
	sta $ff3f
	;
	ldy #$FF
	;
	lda $FF07
	and #$40
	beq il0
	;
	ldy #$F7
	;
il0	ldx #$00
	cpy $FF1D
	bne *-3
	stx $FF06
	stx $FF15
	stx $FF19
	;
	; ---
	;
	jsr PLAYER_INIT
	;
	setptr timeline_ptr,timeline
	jsr progress_timeline
	;
	setptr letters_ptr,letters
	;
	; --- Create bob X lookup table
	;
	ldx #$00
il1	txa
	and #$78
	sta bob_ptr1
	lda #$00
	sta bob_ptr1+1
	;
	asl bob_ptr1
	rol bob_ptr1+1
	asl bob_ptr1
	rol bob_ptr1+1
	asl bob_ptr1
	rol bob_ptr1+1
	;
	lda bob_ptr1
	sta bob_x_lookup_lo,x
	lda bob_ptr1+1
	adc #(chars >> 8)+4
	sta bob_x_lookup_hi,x
	inx
	bne il1
	;
	lda #$00
	ldx #$05
	ldy #(chars >> 8)+2
	jsr fill
	;
	; ---
	;
	jsr square_init
	;
	lda #$00		; triangles font
	ldx #$07 
	ldy #line_font >> 8
	jsr fill
	jsr line_init
	;
	; ---
	;
	setptr text_wipe_ptr1,$0C27
	setptr text_wipe_ptr2,$0ED0
	;
	; ---
	;
	lda $FF07
	and #$40
	ora #$98
	sta $FF07
	;
	lda $FF12
	and #$03
	ora #$C0
	sta $FF12
	;
	lda #chars >> 8
	sta $FF13
	;
	lda #$08
	sta $FF14
	;
	lda #$08		; clear color RAM
	ldy #$08
	jsr fill3
	;
	lda #$00		; clear screen
	ldy #$0C
	jsr fill3
	;
	; ---
	;
	jsr switch_irq_empty
	jsr set_irq_bottom
	asl $FF09
	;
	ldx #$1B
	lda #$F8
	cmp $FF1D
	bne *-3
	stx $FF06
	;
	cli
	;
main	lda #$7F
	sta $FD30
	sta $FF08
	lda $FF08
	and #$10	; Query keyboard for "Space"
	bne main
	;
	lda #$00
	sta $FF11
	sta $FF06
	;
	lda $0500
	cmp #$EA
	beq *+5
	jmp $FFF6
	jmp $0500
	
	;
	; -----------
	; fills a section of the memory with the same byte
	;
	; A = byte to fill
	; X = pages       
	; Y = high byte of address
	;
	; on exit: Y=$00, X=$FF
	;
fill3	ldx #$03	; common entry: fill 4 pages
fill	sty ptr+1
	ldy #$00
	sty ptr
	;	
	; enter from this point to continue fill from last place
	;
fillc	sta (ptr),y	; unroll the loop a bit to gain speed
	iny
	sta (ptr),y
	iny
	sta (ptr),y
	iny
	sta (ptr),y
	iny
	;
	sta (ptr),y
	iny
	sta (ptr),y
	iny
	sta (ptr),y
	iny
	sta (ptr),y
	iny
	;
	bne fillc
	inc ptr+1
	dex
	bpl fillc
	;
	rts
	
	;
	; ptr = destination
	; x,y = width,height
	; a   = byte to fill
	;
fill_area
	sta fa3+1
	dex
	stx fa1+1
	dey
	tya
	tax
fa1	ldy #$00
fa3	lda #$00
fa2	sta (ptr),y
	dey
	bpl fa2
	;
	adcw ptr,40
	;
	dex
	bpl fa1
	;
	rts
	
	align 256
irq_raster
	sta astack
	stx xstack
	sty ystack
	;
	lda $FF1E	; absolute accurate horizontal sync. one cycle = HC increases by 4
	cmp #$3E	
	beq ah16	; ahead by 16
	cmp #$3A
	beq ah12	; ahead by 12
	cmp #$36
	beq ah8		; ahead by 8
	cmp #$32
	beq ah4		; ahead by 4
	cmp #$2E
	beq ah0		; lowest value
	;
ah16	bit $02
ah12	bit $02
ah8	bit $02
ah4	bit $02
ah0	;		; at this point, we're horizontally synced.
	asl $02
	asl $02
	asl $02
	nop
	nop
	;
	; badline: 8(ff15) + 2(nop) + 7(branch taken) + 5(loop) = 22 cycles
	; normal:  8+2+4+2+16+5 = 37 ... 37 + 28 (delay)        = 65 cycles
	;
	ldx #9*8-1
irq_r2	lda colors1,x	;4
	sta $FF15	;4
	nop
	lda badline,x	;4
	bne irq_r3	;3 (taken)
	;
	lda colors2,x	;4
	sta $FF16	;4
	lda colors3,x	;4
	sta $FF17	;4	 = 6*4 = 24
	;
	lda colors4,x	;4
	sta $FF16	;4
	lda colors5,x	;4
	sta $FF17	;4	 = 6*4 = 24
	;
	asl $02		; 28
	asl $02
	nop
	;
irq_r3	dex		;2
	bpl irq_r2	;3 (taken)
	;
	nop
	;
	lda #$00
	sta $FF15
	lda #$31
	sta $FF16
	lda #$51
	sta $FF17
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
switch_irq_fullscreen_color
	lda $FF07
	and #$40
	beq sifc1
	lda #$F7		; NTSC
	db $2C
sifc1	lda #$FF		; PAL
	ldx #irq_fullscreen_color & 255
	ldy #irq_fullscreen_color >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts

switch_irq_empty	
	lda #$42
	ldx #irq_empty & 255
	ldy #irq_empty >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts
	
switch_irq_raster
	lda #$42
	ldx #irq_raster & 255
	ldy #irq_raster >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts
	
switch_irq_floppy
	lda #$43
	ldx #irq_floppy & 255
	ldy #irq_floppy >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts
	
switch_irq_middle_band
	lda #$42
	ldx #irq_middle_band_1 & 255
	ldy #irq_middle_band_1 >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts
	
switch_irq_triangles
	lda #$42
	ldx #irq_triangles_1 & 255
	ldy #irq_triangles_1 >> 8
	sta irq_a
	stx irq_x
	sty irq_y
	rts

set_irq_bottom
	lda #$CC
	ldx #irq_bottom & 255
	ldy #irq_bottom >> 8	
set_irq	sta $FF0B
	stx $FFFE
	sty $FFFF
	rts
	
irq_fullscreen_color
	sta astack
	stx xstack
	sty ystack
	;
	if SOUND_DEBUG
	jmp *+11
	endif
	;
fullscreen_color
	lda #$71
	sta $FF19
	sta $FF15
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_empty
	sta astack
	stx xstack
	sty ystack
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_floppy
	sta astack
	stx xstack
	sty ystack
	;
	lda #$21
	sta $FF15
	;
	lda #$31
	sta $FF16
	lda #$51
	sta $FF17
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_middle_band_1
	sta astack
	stx xstack
	sty ystack
	;
	asl $02
	asl $02
	asl $02
	asl $02
	asl $02
	nop
	nop
	nop
	;
middle_band_color
	lda #$00
	sta $FF19
	sta $FF15
	;
	lda #$8B
	ldx #irq_middle_band_2 & 255
	ldy #irq_middle_band_2 >> 8
	jsr set_irq
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_middle_band_2
	sta astack
	stx xstack
	sty ystack
	;
	asl $02
	asl $02
	asl $02
	asl $02
	nop
	;
	lda #$00
	sta $FF19
	sta $FF15
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_triangles_1
	sta astack
	stx xstack
	sty ystack
	;
	asl $02
	asl $02
	asl $02
	asl $02
	asl $02
	nop
	nop
	nop
	;
triangle_background_color
	lda #$00
	sta $FF19
	sta $FF15
	;
	lda #line_font >> 8
	sta $FF13 
	;
	lda #$8B
	ldx #irq_triangles_2 & 255
	ldy #irq_triangles_2 >> 8
	jsr set_irq
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_triangles_2
	sta astack
	stx xstack
	sty ystack
	;
	asl $02
	asl $02
	asl $02
	asl $02
	nop
	;
	lda #$00
	sta $FF19
	sta $FF15
	;
	lda #chars >> 8
	sta $FF13 
	;
	jsr set_irq_bottom
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti
	
irq_bottom			; bottom!
	sta astack
	stx xstack
	sty ystack
	;
	jsr PLAYER
	;
	ldx #$00
	;
	if SOUND_DEBUG
	lda $FF0E		; sound debug
	cmp #$fe
	beq *+4
	ldx #$31
	endif
	;
	stx $FF15
	;
ff16_color
	lda #$31
	sta $FF16
ff17_color
	lda #$51
	sta $FF17
	;
	if DEBUG
	dec $FF19
	endif
	jsr process_timeline
	if DEBUG
	inc $FF19
	endif
	;
	if DEBUG
	inc $FF19
	endif
	ldx #$00
irq_b1	jsr write_letter_block
speed_write
	bit write_letter_block
	bit write_letter_block
	inx
	cpx #16			; max number of letters
	bne irq_b1
	if DEBUG
	dec $FF19
	endif
	;
	if DEBUG
	dec $FF19
	endif
bob_call
	bit draw_bobs
	if DEBUG
	inc $FF19
	endif
	;
triangles_call
	bit triangles_draw
	;
plasma_call
	bit plasma_draw
	;
	lda irq_a
	ldx irq_x
	ldy irq_y
	jsr set_irq
	;  
	asl $FF09
	lda astack
	ldx xstack
	ldy ystack
	rti

pt1	jsr progress_timeline
process_timeline
	lda timeline_delay
	ora timeline_delay+1
	beq pt1
	;
	lda timeline_delay
	sec
	sbc #$01
	sta timeline_delay
	lda timeline_delay+1
	sbc #$00
	sta timeline_delay+1 
timeline_call
	jmp nothing
	
progress_timeline
	ldy #$00		; get 4 bytes from the timeline table
	lda (timeline_ptr),y	; first two bytes: "length" (in frames)
	sta timeline_delay
	iny 
	lda (timeline_ptr),y
	sta timeline_delay+1
	iny
	lda (timeline_ptr),y	; next 2 bytes: function to call
	sta timeline_call+1
	iny 
	lda (timeline_ptr),y
	sta timeline_call+2
	iny
	tya
	clc
	adc timeline_ptr	; advance the pointer
	sta timeline_ptr
	lda timeline_ptr+1
	adc #$00
	sta timeline_ptr+1
nothing	rts

	;
	; (letters_ptr) points to the next letter in the data.
	; This routine reads that letter (3 bytes), and moves the pointer ahead.
	;
add_next_letter
	ldy #$00
	lda (letters_ptr),y	; first byte: the letter itself
	sta anl1+1
	iny
	lda (letters_ptr),y	; 2nd byte: index
	tax
	iny
	lda (letters_ptr),y	; 3rd byte: screen position (single command byte)
	bpl anl_top
	;
	cmp #$F0		; $F#: full address is stored
	bcc anl_bot
	;
	and #$0F
	sta pos+1
	iny
	lda (letters_ptr),y	; 4th byte: screen position low
	sta pos
	jmp anl3
	;
anl_bot	and #$7F		; when high bit is set,
	clc
	adc #$A8		; position to bottom of screen ($0EA8+##)
	sta pos
	lda #$0E
	adc #$00
	bne anl2		; always jump
	;
anl_top	sta pos			; position to top of screen ($0C##)
	lda #$0C
anl2	sta pos+1
	;
anl3	iny
	tya
	clc
	adc letters_ptr
	sta letters_ptr
	lda letters_ptr+1
	adc #$00
	sta letters_ptr+1
	;
anl1	lda #$00
	jsr add_letter
	rts
	
reset_ff16_ff17
	lda #$31
	sta ff16_color+1
	sta $FF16
	;
	lda #$51
	sta ff17_color+1
	sta $FF17
	;
	rts
	
fade_ff16_ff17
	lda ff16_color+1
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta ff16_color+1
	sta $FF16
	;
	lda ff17_color+1
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta ff17_color+1
	sta $FF17
	;
	rts
	
fade_out_dum
	if DEBUG
	dec $FF19
	endif
	ldx #$0E
fod1	lda $0800+0*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+0*40,x
	;
	lda $0800+1*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+1*40,x
	;
	lda $0800+2*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+2*40,x
	;
	lda $0800+3*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+3*40,x
	;
	lda $0800+4*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+4*40,x
	;
	lda $0800+5*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+5*40,x
	;
	lda $0800+6*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+6*40,x
	;
	dex
	bpl fod1
	;
	jsr fade_ff16_ff17
	;
	if DEBUG
	inc $FF19
	endif
	rts

write_dum
	setptr pos, $0BFF
	lda #$04 ; "d"
	ldx #0
	jsr add_letter
	;
	setptr pos, $0C03
	lda #$1B ; ""
	ldx #1
	jsr add_letter
	;
	setptr pos, $0C07
	lda #$0D ; "m"
	ldx #2
	jsr add_letter
	;
	lda #$20
	db $2C
normal_letter_speed
	lda #$2C
	sta speed_write
	sta speed_write+3
	;
	rts
	
fade_out_plink
	if DEBUG
	dec $FF19
	endif
	ldx #$10
fop1	lda $0AE7+0*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+0*40,x
	;
	lda $0AE7+1*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+1*40,x
	;
	lda $0AE7+2*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+2*40,x
	;
	lda $0AE7+3*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+3*40,x
	;
	lda $0AE7+4*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+4*40,x
	;
	lda $0AE7+5*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+5*40,x
	;
	lda $0AE7+6*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0AE7+6*40,x
	;
	dex
	bpl fop1
	;
	jsr fade_ff16_ff17
	;
	if DEBUG
	inc $FF19
	endif
	rts
	
write_plink
	setptr pos, $0EE7
	lda #$10 ; "p"
	ldx #0
	jsr add_letter
	;
	setptr pos, $0EEB
	lda #$0C ; "l"
	ldx #1
	jsr add_letter
	;
	setptr pos, $0EED
	lda #$09 ; "i"
	ldx #2
	jsr add_letter
	;
	setptr pos, $0EEF
	lda #$0E ; "n"
	ldx #3
	jsr add_letter
	;
	setptr pos, $0EF3
	lda #$0B ; "k"
	ldx #4
	jsr add_letter
	;
	lda #$20
	sta speed_write
	sta speed_write+3
	;
	rts
	
	; a     = letter
	; x     = index
	; (pos) = screen position
add_letter
	tay
	;
	txa
	asl a
	tax
	;
	lda pos
	sta letter_pos,x
	lda pos+1
	sta letter_pos+1,x
	;
	lda char_data_ptrs_lo,y
	sta letter_ptr,x
	lda char_data_ptrs_hi,y
	sta letter_ptr+1,x
	;
	rts
	
write_letter_block
	stx wlb1+1
	;
	txa
	asl a
	tax
	;
	lda letter_ptr,x	; look up this letter's data pointer
	sta pos
	lda letter_ptr+1,x
	sta pos+1
	;
	ldy #$00		; and read the byte from that pointer
	lda (pos),y		; 0 means this letter is done drawing, nothing else to do
	beq wlb1
	;
	clc			; non-zero, add it to our letter's screen position
	adc letter_pos,x
	sta ptr
	lda letter_pos+1,x
	adc #$00
	sta ptr+1
	;
	lda letter_ptr,x	; and move the data pointer ahead
	clc
	adc #$01		; by one byte
	sta letter_ptr,x
	lda letter_ptr+1,x
	adc #$00
	sta letter_ptr+1,x
	;
	jsr put_block		; draw the block on screen
	;
wlb1	ldx #$00		; restore x
	;
	rts

	;
	; input: ptr
	;	
put_block
	lda ptr			; make ptr2 point to the color map
	sta ptr2
	lda ptr+1
	and #$FB
	sta ptr2+1
	;
	; ---
	;
	ldy #40			; center character
	lda (ptr),y
	cmp #1
	beq pb1
	lda #1
	sta (ptr),y
	tax
	lda col,x
	sta (ptr2),y 
	;
	; ---
	;
pb1	ldy #0			; above
	lda (ptr),y
	tax
	lda chr1,x
	bmi pb2
	sta (ptr),y
	tax
	lda col,x
	sta (ptr2),y
	;
pb2	ldy #1			; above right
	lda (ptr),y
	tax
	lda chr2,x
	bmi pb3
	sta (ptr),y
	tax
	lda col,x
	sta (ptr2),y
	;
pb3	ldy #41			; right
	lda (ptr),y
	tax
	lda chr3,x
	bmi pb4
	sta (ptr),y
	tax
	lda col,x
	sta (ptr2),y
	;
pb4	rts

	; lookup tables for block characters
	;   0      1    2  3  4   5  6   7
	; space, full, /-, -, -|, |, |/, L
chr1	db $02,$FF,$02,$FF,$03,$07,$07,$FF
chr2	db $04,$FF,$03,$FF,$04,$FF,$05,$FF
chr3	db $06,$FF,$07,$07,$05,$FF,$06,$FF
col 	db $00,$51,$71,$71,$79,$31,$31,$79

text_wipe
	lda #$00
	ldy #0
	sta (text_wipe_ptr1),y		; clear 7 columns at top and bottom of screen
	sta (text_wipe_ptr2),y
	ldy #40
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	ldy #80
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	ldy #120
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	ldy #160
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	ldy #200
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	ldy #240
	sta (text_wipe_ptr1),y
	sta (text_wipe_ptr2),y
	;
	lda text_wipe_ptr1		; move pointers: top decreases (right to left)
	sec				; only modify low byte ($0C27 -> $0C00), hi byte never overflow
	sbc #$01
	bpl tw1
	;
	lda #$CF
	sta text_wipe_ptr2
	lda #$0E
	sta text_wipe_ptr2+1
	;
	lda #$27
tw1	sta text_wipe_ptr1	
	;
	lda text_wipe_ptr2		; from $0ED0
	clc
	adc #$01			; bottom increases: left to right
	sta text_wipe_ptr2
	lda text_wipe_ptr2+1
	adc #$00
	sta text_wipe_ptr2+1
	;
	rts
	
text_wipe_2
	ldy #$27
	lda #$00
tw2	sta $0C00,y			; wipe two lines: one on top of screen
	sta $0FC0,y			; and one on the bottom
	dey
	bpl tw2
	;
	lda tw2+1			; move top line down
	clc
	adc #40
	sta tw2+1
	bcc *+5
	inc tw2+2
	;
	lda tw2+4			; and bottom line up
	sec
	sbc #40
	sta tw2+4
	bcs *+5
	dec tw2+5
	;
	lda tw2+4			; check if wipe is "done", bottom line pointer reaches $0DB8
	cmp #$B8
	bne tw3
	;
	lda #$00			; reset both pointers
	sta tw2+1
	lda #$0C
	sta tw2+2
	lda #$C0
	sta tw2+4
	lda #$0F
	sta tw2+5
	;
tw3	rts

text_wipe_top
	lda #$00
	ldy #0
	sta (text_wipe_ptr1),y		; clear 7 columns at top of screen
	ldy #40
	sta (text_wipe_ptr1),y
	ldy #80
	sta (text_wipe_ptr1),y
	ldy #120
	sta (text_wipe_ptr1),y
	ldy #160
	sta (text_wipe_ptr1),y
	ldy #200
	sta (text_wipe_ptr1),y
	ldy #240
	sta (text_wipe_ptr1),y
	;
	lda text_wipe_ptr1		; move pointers: top decreases (right to left)
	sec				; only modify low byte ($0C27 -> $0C00), hi byte never overflow
	sbc #$01
	bpl twt1
	;
	lda #$27
twt1	sta text_wipe_ptr1	
	;
	rts

wipe_800
	ldy #$08
	db $2C	
wipe_900
	ldy #$09
	db $2C
wipe_A00
	ldy #$0A
	db $2C	
wipe_B00
	ldy #$0B
	lda #$08
	ldx #$00
	jmp fill
	
wipe_C00
	lda #$00
	tay
	sta $0C00,y
	iny
	bne *-4
	rts
	
wipe_D00
	lda #$00
	tay
	sta $0D00,y
	iny
	bne *-4
	rts
	
wipe_E00
	lda #$00
	tay
	sta $0E00,y
	iny
	bne *-4
	rts
	
wipe_F00
	lda #$00
	tay
	sta $0F00,y
	iny
	bne *-4
	rts

set_text_yellow
	lda #$07
	db $2C	
set_text_gray
	lda #$01
	db $2C
set_text_blue
	lda #$06
	db $2C	
set_text_purple	
	lda #$04
	sta fullscreen_color+1
	;
	ora #$30
	sta ff16_color+1
	sta $FF16
	;       
	and #$0F
	ora #$50
	sta ff17_color+1
	sta $FF17
	;
	sta col+1
	;
	and #$0F
	ora #$70
	sta col+2
	sta col+3
	ora #$08
	sta col+4
	sta col+7
	and #$37
	sta col+5
	sta col+6
	rts
	
purple_plus_letter
	jsr set_text_purple		; have to do these two on one frame
	jmp add_next_letter
	
set_fullscreen_color_black
	lda #$00
	sta fullscreen_color+1
	rts
	
set_drums_colors
	ldx #$00
	lda drums_colors,x
	sta fullscreen_color+1
	inc set_drums_colors+1
	rts

drums_colors
	db $61,$51,$41,0,0
	db 0,0,0,0,0
	db $61,$51,$41,0,0
	;
	db $61,$51,$41,0,0
	db 0,0,0,0,0
	db $61,$51,$41,0,0
	;
	db $61,$51,$41,0,0
	db $61,$51,$41,0,0
	db $61,$51,$41,0,0
	;
	db $61,$51,$41,0,0
	db $61,$51,$41,0,0
	db $61,$51,$41,0,0
	;
	; ###################################################################
	;

raster_prepare
	setptr ptr,$0C00+8*40
	ldx #40
	ldy #9
	lda #$01
	jsr fill_area
	;
	jsr switch_irq_raster
	;
	jmp normal_letter_speed
	
raster_draw_square_1
	setptr ptr,$0C00+10*40+1
	ldx #$05			; 5x5
	ldy #$05
	lda #$0A			; char
	jmp fill_area

raster_draw_square_2
	setptr ptr,$0C00+9*40+7
	ldx #$07			; 7x7
	ldy #$07
	lda #$09			; char
	jmp fill_area
	
raster_draw_square_3
	setptr ptr,$0C00+8*40+15
	ldx #$09			; 9x9
	ldy #$09
	lda #$08			; char
	jmp fill_area

raster_draw_square_4
	setptr ptr,$0C00+9*40+25
	ldx #$07			; 7x7
	ldy #$07
	lda #$0A			; char
	jmp fill_area

raster_draw_square_5
	setptr ptr,$0C00+10*40+33
	ldx #$05			; 5x5
	ldy #$05
	lda #$09			; char
	jmp fill_area
	
raster_fadeout
	ldy #$07
	;
	lda #$FF
	sta chars+8*8,y
	sta chars+9*8,y
	sta chars+10*8,y
	;
	dey
	sty raster_fadeout+1
	rts
	
	;
	; ###################################################################
	;
bobs_prepare
	setptr ptr,$0C00+8*40
	;
	ldx #$00
bp2	txa
	clc
	adc #$10
	ldy #$00
bp1	ora #$80
	sta (ptr),y
	clc
	adc #$08
	iny
	cpy #40
	bne bp1
	;
	adcw ptr,40
	;
	inx
	cpx #9
	bne bp2
	;
	; ---
	;
	setptr ptr,$0800+8*40
	ldx #40
	ldy #9
	lda #$17		; bob color
	jsr fill_area
	;
	ldx #$01
	stx bob_count
	;
	ldx #MAX_BOB_COUNT-1
bp3	txa
	asl a
	asl a
	sta bob_x_pos,x
	sta bob_y1_pos,x
	sta bob_y2_pos,x
	dex
	bpl bp3
	;
	; ---
	;
	jsr switch_irq_empty
	;
	rts

bobs_disable
	lda #$2C
	db $2C
bobs_enable
	lda #$20
	sta bob_call
	rts
	
middle_band_fade_in
	ldx #$01
	lda middle_band_colors,x
	sta middle_band_color+1
	;
	inc middle_band_fade_in+1
	;
	rts
	
middle_band_fade_out
	ldx #$09
	lda middle_band_colors,x
	sta middle_band_color+1
	;
	dec middle_band_fade_out+1
	;
	rts
	
middle_band_colors
	db $00,$01,$07,$17,$27,$37,$3A,$49,$57,$69,$67
middle_band_colors_end

add_one_bob
	lda $FF07
	and #$40
	beq aob_pal
	;
	lda bob_count
	cmp #10-1			; NTSC: 10 max
	bne aob
	rts
	;
aob_pal	lda bob_count
	cmp #19-1			; PAL: 19 max
	bne aob
	rts
	;
aob	lda #$01
	sta bob_add+1
	rts

sub_one_bob
	lda #$01
	sta bob_sub+1
	rts
	
draw_bobs
	;
	; --- clear bobs
	;
	lda bob_count			; do nothing with 0 count
	bne *+3
	rts
	;
	ldx #$00
db1	lda bob_x_pos,x
	tay
	lda bob_sine_X,y
	tay
	lda bob_x_lookup_lo,y
	sta bob_ptr1
	lda bob_x_lookup_hi,y
	sta bob_ptr1+1
	;
	lda bob_ptr1
	ldy bob_y1_pos,x
	clc
	adc bob_sine_1,y
	sta bob_ptr1
	bcc *+4
	inc bob_ptr1+1
	;
	lda bob_ptr1
	ldy bob_y2_pos,x
	clc
	adc bob_sine_2,y
	sta bob_ptr1
	bcc *+4
	inc bob_ptr1+1
	;
	lda bob_ptr1
	clc
	adc #$40
	sta bob_ptr2
	lda bob_ptr1+1
	adc #$00
	cmp #(chars >> 8)+8
	bne *+5
	sec
	sbc #$04
	sta bob_ptr2+1
	;
	lda #$00		; clear the bob gfx
	tay			; 8 bytes in 2 columns
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	iny
	sta (bob_ptr1),y
	sta (bob_ptr2),y
	;
	inx
	cpx bob_count
	bne db1
	;
	; --- move bobs (all of them, even the ones not visible)
	;
	ldx #$00
db2	lda bob_x_pos,x
	sec
	sbc #$01
	bpl *+4
	lda #(bob_sine_X_end-bob_sine_X)-1
	sta bob_x_pos,x
	;
	lda bob_y1_pos,x
	clc
	adc #$01
	cmp #bob_sine_1_end-bob_sine_1
	bne *+4
	lda #$00
	sta bob_y1_pos,x
	;
	lda bob_y2_pos,x
	sec
	sbc #$01
	bpl *+4
	lda #(bob_sine_2_end-bob_sine_2)-1
	sta bob_y2_pos,x
	;
	inx
	cpx #MAX_BOB_COUNT
	bne db2
	;
	; ---
	;
	lda bob_count
	clc
bob_add	adc #$00
	sec
bob_sub	sbc #$00
	sta bob_count
	lda #$00
	sta bob_add+1
	sta bob_sub+1
	;
	; --- draw bobs
	;
	lda bob_count			; do nothing with 0 count
	bne *+3
	rts
	;
	ldx #$00
db3	lda bob_x_pos,x
	tay
	lda bob_sine_X,y
	and #$07
	tay
	lda bob_bytes1,y
	sta bob_byte1
	lda bob_bytes2,y
	sta bob_byte2
	;
	lda bob_x_pos,x
	tay
	lda bob_sine_X,y
	tay
	lda bob_x_lookup_lo,y
	sta bob_ptr1
	lda bob_x_lookup_hi,y
	sta bob_ptr1+1
	;
	lda bob_ptr1
	ldy bob_y1_pos,x
	clc
	adc bob_sine_1,y
	sta bob_ptr1
	bcc *+4
	inc bob_ptr1+1
	;
	lda bob_ptr1
	ldy bob_y2_pos,x
	clc
	adc bob_sine_2,y
	sta bob_ptr1
	bcc *+4
	inc bob_ptr1+1
	;
	lda bob_ptr1
	clc
	adc #$40
	sta bob_ptr2
	lda bob_ptr1+1
	adc #$00
	cmp #(chars >> 8)+8
	bne *+5
	sec
	sbc #$04
	sta bob_ptr2+1
	;
	ldy #$00
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	iny
	lda (bob_ptr1),y
	ora bob_byte1
	sta (bob_ptr1),y
	lda (bob_ptr2),y
	ora bob_byte2
	sta (bob_ptr2),y
	;
	inx
	cpx bob_count
	beq db4
	jmp db3
	;
db4	rts
	
bob_x_pos
	ds MAX_BOB_COUNT
bob_y1_pos
	ds MAX_BOB_COUNT
bob_y2_pos
	ds MAX_BOB_COUNT
	
	align 128
bob_sine_X
; 97,56
	db $38,$3C,$3F,$43,$46,$4A,$4D,$51,$54,$57,$5A,$5D,$5F,$62,$64,$66
	db $68,$6A,$6B,$6D,$6E,$6F,$6F,$70,$70,$70,$70,$6F,$6E,$6D,$6C,$6B
	db $69,$67,$65,$63,$61,$5E,$5B,$58,$55,$52,$4F,$4C,$48,$45,$41,$3D
	db $3A,$36,$33,$2F,$2B,$28,$24,$21,$1E,$1B,$18,$15,$12,$0F,$0D,$0B
	db $09,$07,$05,$04,$03,$02,$01,$00,$00,$00,$00,$01,$01,$02,$03,$05
	db $06,$08,$0A,$0C,$0E,$11,$13,$16,$19,$1C,$1F,$23,$26,$2A,$2D,$31
	db $34
bob_sine_X_end

	align 128	
bob_sine_1
; 103,25,8
	db $21,$23,$24,$26,$27,$29,$2A,$2B,$2D,$2E,$2F,$31,$32,$33,$34,$35
	db $36,$37,$37,$38,$38,$39,$39,$3A,$3A,$3A,$3A,$3A,$3A,$3A,$39,$39
	db $38,$38,$37,$36,$35,$34,$33,$32,$31,$30,$2F,$2D,$2C,$2B,$29,$28
	db $26,$25,$23,$22,$20,$1F,$1D,$1C,$1A,$19,$17,$16,$15,$13,$12,$11
	db $10,$0F,$0E,$0D,$0C,$0B,$0A,$0A,$09,$09,$08,$08,$08,$08,$08,$08
	db $08,$09,$09,$0A,$0A,$0B,$0B,$0C,$0D,$0E,$0F,$10,$11,$13,$14,$15
	db $17,$18,$19,$1B,$1C,$1E,$1F
bob_sine_1_end

	align 128
bob_sine_2
; 71,30
	db $1E,$21,$23,$26,$28,$2B,$2D,$2F,$32,$33,$35,$37,$38,$39,$3A,$3B
	db $3C,$3C,$3C,$3C,$3B,$3B,$3A,$39,$38,$36,$34,$32,$30,$2E,$2C,$2A
	db $27,$25,$22,$1F,$1D,$1A,$17,$15,$12,$10,$0E,$0C,$0A,$08,$06,$04
	db $03,$02,$01,$01,$00,$00,$00,$00,$01,$02,$03,$04,$05,$07,$09,$0A
	db $0D,$0F,$11,$14,$16,$19,$1B
bob_sine_2_end

	;
	; ###################################################################
	;
plasma_enable
	lda #$20
	db $2C
plasma_disable
	lda #$2C
	sta plasma_call
	rts
	
plasma_prepare
	ldx #$7F
plpr1	lda plasma_chars,x
	sta chars+$780,x
	dex
	bpl plpr1
	;
	jsr switch_irq_empty
	;
	rts
	
plasma_height_inc
	inc plasma_height+1
	rts 
	
plasma_color_fade_out
	if DEBUG
	dec $FF19
	endif
	;
	ldx #(final_colors_end-final_colors)-1
pcfo1	lda final_colors,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta final_colors,x
	dex
	bpl pcfo1
	;
	if DEBUG
	inc $FF19
	endif
	rts
	
	;
	; ###################################################################
	;
enable_triangles
	lda #$20
	db $2C
disable_triangles
	lda #$2C
	sta triangles_call
	rts
	
triangles_prepare_color
	setptr ptr,$0800+8*40+0*8
	ldx #8
	ldy #9
	lda #$57
	jsr fill_area
	;
	setptr ptr,$0800+8*40+1*8
	ldx #8
	ldy #9
	lda #$67
	jsr fill_area
	;
	setptr ptr,$0800+8*40+2*8
	ldx #8
	ldy #9
	lda #$77
	jsr fill_area
	;
	setptr ptr,$0800+8*40+3*8
	ldx #8
	ldy #9
	lda #$67
	jsr fill_area
	;
	setptr ptr,$0800+8*40+4*8
	ldx #8
	ldy #9
	lda #$57
	jsr fill_area
	;
	rts
	
triangle_background_fade_in
	ldx #$01
	lda triangle_background_colors,x
	sta triangle_background_color+1
	;
	inc triangle_background_fade_in+1
	rts
	
triangle_background_fade_out
	ldx #$07
	lda triangle_background_colors,x
	sta triangle_background_color+1
	;
	dec triangle_background_fade_out+1
	;
	ldx #40*2-1
tbfo1	lda $0800+8*40,x
	sec
	sbc #$10
	bpl *+4
	lda #$00
	sta $0800+8*40,x
	dex
	bpl tbfo1
	rts
	
triangle_background_colors
	db $00,$01,$0F,$1F,$2F,$3A,$3F,$45,$4A
	
triangle_stop_rotation
	lda #$01
	sta tdly1a+1
	sta tdly2a+1
	sta tdly3a+1
	rts
	
add_strikethrough
	lda #$2C
	sta ptr
	lda #$0F
	sta ptr+1
	;
	jsr put_block
	;
	inc add_strikethrough+1
	;
	rts
	
	;
	; ###################################################################
	;
floppy_prepare
	if debug
	dec $FF19
	endif
	;
	lda #$0B			; screen off
	sta $FF06
	;
	ldx #$00
fp1	lda floppy_chars,x
	sta $0C00+8*40,x
	lda floppy_chars+$100,x
	sta $0C00+8*40+$100,x
	inx
	bne fp1
	;
	ldx #$A8
fp2	lda floppy_chars+$200-1,x
	sta $0C00+8*40+$200-1,x
	dex
	bne fp2
	;
	setptr ptr,$0800+8*40
	ldx #40
	ldy #17
	lda #$00
	jsr fill_area
	;
	setptr ptr,$0800+14*40+17
	ldx #5
	ldy #5
	lda #$79
	jsr fill_area
	;
	setptr ptr,$0800+20*40+18
	ldx #3
	ldy #5
	lda #$31
	jsr fill_area
	;
	lda #$31
	sta $0800+17*40+22
	;
	jsr switch_irq_floppy
	;
	jsr set_text_gray
	jsr write_the
	;
	lda #$1B			; screen off
	sta $FF06
	;
	if debug
	inc $FF19
	endif
	;
	rts
	
write_the
	ldx #$34
	stx $0C06
	inx
	stx $0C06+1
	inx
	stx $0C06+2
	;
	lda #$51
	sta $0806
	sta $0806+1
	sta $0806+2
	rts
	
check_disk
	lda $10
	cmp #$08
	beq cd1
	;
	setptr timeline_ptr,tl2		; skip "flip disk", if last device is NOT $08
	setptr letters_ptr,let2
	;
cd1	rts

timeline_jump_back
	setptr timeline_ptr,tl1
	setptr letters_ptr,let1
	rts
	
	;
	; ###################################################################
	; timeline!	
timeline
	dw 1,write_dum
	dw 6,nothing
	dw 8,fade_out_dum
	dw 13,nothing
	dw 1,wipe_C00
	dw 1,reset_ff16_ff17
	dw 1,write_plink
	dw 6,nothing
	dw 8,fade_out_plink
	dw 12,nothing
	dw 1,wipe_E00
	dw 1,wipe_F00
	dw 1,reset_ff16_ff17
	;
	dw 1,write_dum
	dw 6,nothing
	dw 8,fade_out_dum
	dw 13,nothing
	dw 1,wipe_C00
	dw 1,reset_ff16_ff17
	dw 1,write_plink
	dw 6,nothing
	dw 8,fade_out_plink
	dw 12,nothing
	dw 1,wipe_E00
	dw 1,wipe_F00
	dw 1,reset_ff16_ff17
	;
	dw 1,write_dum
	dw 6,nothing
	dw 8,fade_out_dum
	dw 13,nothing
	dw 1,wipe_C00
	dw 1,reset_ff16_ff17
	dw 1,write_plink
	dw 6,nothing
	dw 8,fade_out_plink
	dw 11,nothing
	dw 1,normal_letter_speed
	dw 1,wipe_E00
	dw 1,wipe_F00
	dw 1,reset_ff16_ff17
	;
	dw 1,switch_irq_fullscreen_color
	dw 5*12-1,set_drums_colors
	;
	dw 1,purple_plus_letter		; square waves, square pixels
	dw 10,add_next_letter
	dw 64,nothing
	dw 1,add_next_letter
	dw 9,nothing
	dw 1,add_next_letter
	dw 14,nothing
	dw 1,add_next_letter
	dw 19,nothing
	;
	dw 12,add_next_letter
	dw 48,nothing
	dw 1,add_next_letter
	dw 14,nothing
	dw 1,add_next_letter
	dw 9,nothing
	dw 1,add_next_letter
	dw 20,nothing
	dw 13,text_wipe_2
	;
	dw 1,set_text_blue		; everything is...
	dw 10,add_next_letter
	dw 110,nothing
	dw 5,add_next_letter
	dw 100,nothing
	dw 13,text_wipe_2
	dw 1,set_fullscreen_color_black
	dw 1,switch_irq_empty
	;
	dw 1,square_start
	;
	; -----------			; raster?
	dw 1,wipe_900
	dw 1,wipe_A00
	dw 1,set_text_gray
	dw 1,raster_prepare
	dw 8,add_next_letter
	dw 16,nothing
	dw 1,raster_draw_square_1
	dw 31,nothing
	dw 1,raster_draw_square_2
	dw 31,nothing
	dw 1,raster_draw_square_3
	dw 15,nothing
	dw 1,raster_draw_square_4
	dw 15,nothing
	dw 1,raster_draw_square_5
	dw 7,nothing
	dw 7,add_next_letter
	dw 50,nothing
	dw 40,text_wipe
	dw 8,raster_fadeout
	;
	dw 1,bobs_prepare		; bobs?
	dw 5,add_next_letter
	dw 10,nothing
	dw 1,switch_irq_middle_band
	dw 10,middle_band_fade_in
	dw 1,bobs_enable
	dw 105,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 1,add_one_bob,3,nothing
	dw 105,nothing
	dw 7,add_next_letter
	dw 86,nothing
	dw 19,sub_one_bob
	dw 1,bobs_disable
	dw 40,text_wipe
	dw 10,middle_band_fade_out
	;
	dw 1,wipe_D00
	dw 1,wipe_E00
	dw 1,plasma_prepare		; plasma?
	dw 7,add_next_letter
	dw 55,nothing
	dw 1,plasma_enable
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 1,plasma_height_inc,1,nothing
	dw 150,nothing
	dw 7,add_next_letter
	dw 170,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out,3,nothing
	dw 1,plasma_color_fade_out
	dw 1,plasma_disable
	dw 40,text_wipe
	dw 1,wipe_D00
	dw 1,wipe_E00
	;                        
	dw 1,switch_irq_triangles
	dw 1,triangles_prepare		; triangles
	dw 1,triangles_prepare_color
	dw 10,add_next_letter
	dw 40,nothing
	dw 8,triangle_background_fade_in
	dw 1,enable_triangles
	dw 150,nothing
	dw 8,add_next_letter
	dw 40,nothing
	dw 27,add_strikethrough
	dw 40,nothing
	dw 1,triangle_stop_rotation
	dw 97,nothing
	dw 8,triangle_background_fade_out
	dw 3,nothing
	dw 1,disable_triangles
	dw 40,text_wipe
	dw 1,wipe_D00
	dw 1,wipe_E00
	dw 1,wipe_900
	dw 1,wipe_A00
	dw 1,switch_irq_fullscreen_color

	dw 1,set_text_yellow		; most square of them all
	dw 3,add_next_letter
	dw 10,nothing
	dw 4,add_next_letter
	dw 10,nothing
	dw 6,add_next_letter
	dw 10,nothing
	dw 9,add_next_letter
	dw 58,nothing
	dw 13,text_wipe_2
	dw 1,set_fullscreen_color_black
	dw 1,switch_irq_empty
	
	dw 1,floppy_prepare		; floppy
	dw 11,add_next_letter
	dw 4*50,nothing
	dw 40,text_wipe_top
	;
tl1	dw 1,check_disk
	dw 9,add_next_letter
	dw 4*50,nothing
	dw 40,text_wipe_top
	;
tl2	dw 10,add_next_letter
	dw 4*50,nothing
	dw 40,text_wipe_top
	dw 1,timeline_jump_back
	
	dw $FFFF,nothing
 
	cmap "a",1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26
	cmap "",$1B
	cmap ".",$1C
	cmap "?",$1D
	cmap "!",$1E
	cmap "A",$21,$22,$23,$24,$25,$26,$27,$28,$29,$2A,$2B,$2C,$2D,$2E,$2F,$30,$31,$32,$33,$34,$35,$36,$37,$38,$39,$3A
letters
	db "s", 0,$FB,$D7
	db "q", 1,$FB,$DB
	db "u", 2,$FB,$DF
	db "a", 3,$FB,$E3
	db "r", 4,$FB,$E7
	db "e", 5,$FB,$EB
	db "w", 6,$FC,$D3
	db "a", 7,$FC,$D9
	db "v", 8,$FC,$DD
	db "e", 9,$FC,$E1
	db "s",11,$FC,$E5
	db ".",12,$FC,$E9
	db ".",13,$FC,$EB
	db ".",14,$FC,$ED
	;
	db "s", 0,$FD,$B7
	db "q", 1,$FD,$BB
	db "u", 2,$FD,$BF
	db "a", 3,$FD,$C3
	db "r", 4,$FD,$C7
	db "e", 5,$FD,$CB
	db "p", 6,$80+13
	db "i", 7,$80+17
	db "x", 8,$80+19
	db "e", 9,$80+23
	db "l",10,$80+27
	db "s",11,$80+29
	db ".",12,$80+33
	db ".",13,$80+35
	db ".",14,$80+37
	;
	db "e", 0,$FD,$18
	db "v", 1,$FD,$1C
	db "e", 2,$FD,$20
	db "r", 3,$FD,$24
	db "y", 4,$FD,$28
	db "T", 5,$FD,$2C
	db "H", 6,$FD,$30
	db "i", 7,$FD,$34
	db "n", 8,$FD,$36
	db "g", 9,$FD,$3A
	;
	db "i",10,$FE,$16
	db "s",11,$FE,$18
	db ".",12,$FE,$1C
	db ".",13,$FE,$1E
	db ".",14,$FE,$20
	;
	db "r",0,0
	db "a",1,4
	db "s",2,8
	db "t",3,12
	db "e",4,15
	db "r",5,19
	db "s",6,23
	db "?",7,27
	
	db "s",0,$80+13
	db "q",1,$80+17
	db "u",2,$80+21
	db "a",3,$80+25
	db "r",4,$80+29
	db "e",5,$80+33
	db "!",6,$80+37
	
	db "b",0,0
	db "o",1,4
	db "b",2,8
	db "s",3,12
	db "?",7,16
	
	db "s",0,$80+13
	db "q",1,$80+17
	db "u",2,$80+21
	db "a",3,$80+25
	db "r",4,$80+29
	db "e",5,$80+33
	db "!",6,$80+37
	
	db "p",0,0
	db "l",1,4
	db "a",2,6
	db "s",3,10
	db "m",4,14
	db "a",5,20
	db "?",6,24
	
	db "s",0,$80+13
	db "q",1,$80+17
	db "u",2,$80+21
	db "a",3,$80+25
	db "r",4,$80+29
	db "e",5,$80+33
	db "!",6,$80+37
	
	db "t",0,0
	db "r",1,3
	db "i",2,7
	db "a",3,9 
	db "n",4,13
	db "g",5,17
	db "l",6,21
	db "e",7,23
	db "s",8,27
	db "?",9,31
	
	db "s",0,$80+13
	db "q",1,$80+17
	db "u",2,$80+21
	db "a",3,$80+25
	db "!",4,$80+29
	db ".",5,$80+31
	db ".",6,$80+33
	db ".",6,$80+35
	
	db "t", 0,0
	db "h", 1,3
	db "e", 2,7
	db "m", 3,13
	db "o", 4,19
	db "s", 5,23
	db "t", 6,27
	
	db "s", 0,$FD,$40
	db "q", 1,$FD,$44
	db "u", 2,$FD,$48
	db "a", 3,$FD,$4C
	db "r", 4,$FD,$50
	db "e", 5,$FD,$54
	
	db "o", 0,$80+0
	db "f", 1,$80+4
	db "t", 2,$80+9
	db "h", 3,$80+12
	db "e", 4,$80+16
	db "m", 5,$80+20
	db "a", 6,$80+28
	db "l", 7,$80+32
	db "l", 8,$80+34
	
	db "f",0,0
	db "l",1,3
	db "o",2,5
	db "p",3,9
	db "p",4,13
	db "y",5,17
	db "d",6,23
	db "i",7,27
	db "s",8,29
	db "k",9,33
	db "!",10,37
	
let1	db "f",0,6
	db "l",1,9
	db "i",2,11
	db "p",3,13
	db "d",4,18
	db "i",5,22
	db "s",6,24
	db "k",7,28
	db "!",8,32
	
let2	db "p",0,$FB,$FF
	db "R",1,3
	db "e",2,6
	db "s",3,10
	db "s",4,14
	db "s",5,19
	db "p",6,23
	db "a",7,27
	db "c",8,31
	db "e",9,35
	
	cmap
	
	align 32
	; holds the screen position of each letter
letter_pos
	dw $0FE8,$0FE8,$0FE8,$0FE8
	dw $0FE8,$0FE8,$0FE8,$0FE8
	dw $0FE8,$0FE8,$0FE8,$0FE8
	dw $0FE8,$0FE8,$0FE8,$0FE8
	; points to the character data of the current letter
letter_ptr
	dw c_none,c_none,c_none,c_none
	dw c_none,c_none,c_none,c_none
	dw c_none,c_none,c_none,c_none
	dw c_none,c_none,c_none,c_none
	
;widths	db 4,4,4,4,4,4,4,4,2,4,4,4,6
;	db 4,4,4,4,4,4,4,4,4,6,4,4,4
;	db 2,4,2
	
char_data_ptrs_lo
	db c_none & 255
	db c_low_a & 255
	db c_low_b & 255
	db c_low_c & 255
	db c_low_d & 255
	db c_low_e & 255
	db c_low_f & 255
	db c_low_g & 255
	db c_low_h & 255
	db c_low_i & 255
	db c_low_j & 255
	db c_low_k & 255
	db c_low_l & 255
	db c_low_m & 255
	db c_low_n & 255
	db c_low_o & 255
	db c_low_p & 255
	db c_low_q & 255
	db c_low_r & 255
	db c_low_s & 255
	db c_low_t & 255
	db c_low_u & 255
	db c_low_v & 255
	db c_low_w & 255
	db c_low_x & 255
	db c_low_y & 255
	db c_low_z & 255
	db c_u_uml & 255
	db c_dot & 255
	db c_ques & 255
	db c_excl & 255
	db c_none & 255
	;
	db c_none & 255
	db c_low_a & 255
	db c_low_b & 255
	db c_low_c & 255
	db c_low_d & 255
	db c_low_e & 255
	db c_low_f & 255
	db c_low_g & 255
	db c_upp_h & 255
	db c_low_i & 255
	db c_low_j & 255
	db c_low_k & 255
	db c_low_l & 255
	db c_low_m & 255
	db c_low_n & 255
	db c_low_o & 255
	db c_low_p & 255
	db c_low_q & 255
	db c_upp_r & 255
	db c_low_s & 255
	db c_upp_t & 255
	db c_low_u & 255
	db c_low_v & 255
	db c_low_w & 255
	db c_low_x & 255
	db c_low_y & 255
	db c_low_z & 255
	
char_data_ptrs_hi
	db c_none >> 8
	db c_low_a >> 8
	db c_low_b >> 8
	db c_low_c >> 8
	db c_low_d >> 8
	db c_low_e >> 8
	db c_low_f >> 8
	db c_low_g >> 8
	db c_low_h >> 8
	db c_low_i >> 8
	db c_low_j >> 8
	db c_low_k >> 8
	db c_low_l >> 8
	db c_low_m >> 8
	db c_low_n >> 8
	db c_low_o >> 8
	db c_low_p >> 8
	db c_low_q >> 8
	db c_low_r >> 8
	db c_low_s >> 8
	db c_low_t >> 8
	db c_low_u >> 8
	db c_low_v >> 8
	db c_low_w >> 8
	db c_low_x >> 8
	db c_low_y >> 8
	db c_low_z >> 8
	db c_u_uml >> 8
	db c_dot >> 8
	db c_ques >> 8
	db c_excl >> 8
	db c_none >> 8
	;
	db c_none >> 8
	db c_low_a >> 8
	db c_low_b >> 8
	db c_low_c >> 8
	db c_low_d >> 8
	db c_low_e >> 8
	db c_low_f >> 8
	db c_low_g >> 8
	db c_upp_h >> 8
	db c_low_i >> 8
	db c_low_j >> 8
	db c_low_k >> 8
	db c_low_l >> 8
	db c_low_m >> 8
	db c_low_n >> 8
	db c_low_o >> 8
	db c_low_p >> 8
	db c_low_q >> 8
	db c_upp_r >> 8
	db c_low_s >> 8
	db c_upp_t >> 8
	db c_low_u >> 8
	db c_low_v >> 8
	db c_low_w >> 8
	db c_low_x >> 8
	db c_low_y >> 8
	db c_low_z >> 8
	
c_low_a	db $7A,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$2A,$29,$00
c_low_b	db $2A,$2B,$53,$7B,$A3,$CB,$CA,$C9,$A1,$79,$51,$29,$01,$00
c_low_c	db $2B,$2A,$29,$51,$79,$A1,$C9,$CA,$CB,$00
c_low_d	db $2A,$29,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$03,$00
c_low_e	db $7A,$7B,$53,$2B,$2A,$29,$51,$79,$A1,$C9,$CA,$CB,$00
c_low_f	db $02,$01,$29,$51,$79,$A1,$C9,$52,$00
c_low_g	db $2B,$2A,$29,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$00
c_low_h	db $01,$29,$51,$79,$A1,$C9,$2A,$2B,$53,$7B,$A3,$CB,$00
c_low_i	db $01,$51,$79,$A1,$C9,$00
c_low_j	db $A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$00
c_low_k	db $C9,$A1,$79,$51,$29,$2B,$53,$7A,$A3,$CB,$00
c_low_l	db $01,$29,$51,$79,$A1,$C9,$00
c_low_m	db $C9,$A1,$79,$51,$29,$2A,$2B,$53,$7B,$A3,$CB,$2C,$2D,$55,$7D,$A5,$CD,$00
c_low_n	db $C9,$A1,$79,$51,$29,$2A,$2B,$53,$7B,$A3,$CB,$00
c_low_o	db $2A,$29,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$00
c_low_p	db $7A,$7B,$53,$2B,$2A,$29,$51,$79,$A1,$C9,$00
c_low_q	db $F3,$CA,$C9,$A1,$79,$51,$29,$2A,$2B,$53,$7B,$A3,$CB,$00
c_low_r	db $C9,$A1,$79,$51,$29,$2A,$2B,$53,$00
c_low_s	db $2B,$2A,$29,$51,$79,$7A,$7B,$A3,$CB,$CA,$C9,$00
c_low_t	db $01,$29,$51,$79,$A1,$C9,$CA,$2A,$00
c_low_u	db $29,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$00
c_low_v	db $29,$51,$79,$A1,$CA,$A3,$7B,$53,$2B,$00
c_low_w	db $29,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$2B,$CC,$CD,$A5,$7D,$55,$2D,$00
c_low_x	db $2B,$53,$7A,$A1,$C9,$29,$51,$A3,$CB,$00
c_low_y	db $29,$51,$79,$7A,$7B,$53,$2B,$A2,$CA,$00
c_low_z	db $29,$2A,$2B,$53,$7A,$A1,$C9,$CA,$CB,$00
c_u_uml	db $01,$51,$79,$A1,$C9,$CA,$CB,$A3,$7B,$53,$03,$00
c_dot	db $C9,$00
c_ques	db $29,$2A,$2B,$53,$7B,$7A,$CA,$00
c_excl	db $29,$51,$79,$C9
c_none	db $00

c_upp_h	db $29,$51,$79,$A1,$C9,$2B,$53,$7B,$A3,$CB,$7A,$00
c_upp_f	db $7A,$79,$A1,$C9,$2B,$2A,$29,$51,$00
c_upp_l	db $29,$51,$79,$A1,$C9,$CA,$CB,$00
c_upp_r	db $C9,$A1,$79,$51,$29,$2A,$00
c_upp_t	db $29,$2A,$2B,$52,$7A,$A2,$CA,$00

bob_bytes1
	db $FF,$7F,$3F,$1F,$0F,$07,$03,$01
bob_bytes2
	db $00,$80,$C0,$E0,$F0,$F8,$FC,$FE

floppy_chars	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$0B,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$0C,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$0F,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$1B,$1C,$1D,$1E,$1F,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$20,$21,$22,$23,$24,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$25,$26,$27,$28,$29,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$2A,$2B,$2C,$2D,$2E,$1A,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$2F,$30,$31,$32,$33,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$12,$13,$14,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$15,$01,$16,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$15,$01,$16,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$00,$00,$00,$00,$00
	db $00,$00,$15,$01,$16,$00,$00,$00
	db $00,$00,$00,$00,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	db $01,$01,$01,$01,$01,$01,$01,$01
	db $01,$01,$01,$0D,$00,$00,$00,$00
	db $00,$10,$17,$18,$19,$11,$00,$00
	db $00,$00,$00,$0E,$01,$01,$01,$01
	db $01,$01,$01,$01,$01,$01,$01,$01
	
	; these must be page aligned, to ensure the indexed lookup doesn't cross page boundaries 
	align 256	
badline
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	db 1,0,0,0,0,0,0,1
	
colors1
	db $04,$14,$24,$34,$44,$54,$64,$74
	db $64,$54,$44,$34,$34,$44,$54,$64
	db $74,$64,$54,$44,$34,$24,$14,$04
	db $0b,$1b,$2b,$3b,$4b,$5b,$6b,$7b
	db $6b,$5b,$4b,$3b,$3b,$4b,$5b,$6b
	db $7b,$6b,$5b,$4b,$3b,$2b,$1b,$0b
	db $02,$12,$22,$32,$42,$52,$62,$72
	db $62,$52,$42,$32,$32,$42,$52,$62
	db $72,$62,$52,$42,$32,$22,$12,$02
	
	; in these tables, 2 bytes marked with $FF are not used (badline)
colors2
	db 0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0
	db $FF,$6C,$5C,$4C,$3C,$2C,$5C,$FF
	db $FF,$5C,$2C,$3C,$4C,$5C,$6C,$FF
	db $FF,$6C,$5C,$4C,$43,$53,$63,$FF
	db $FF,$63,$53,$43,$33,$23,$53,$FF
	db $FF,$53,$23,$33,$43,$53,$63,$FF
	db 0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0
	
	align 256
colors3
	db 0,0,0,0,0,0,0,0
	db $FF,$6A,$5A,$4A,$3A,$4A,$5A,$FF
	db $FF,$6A,$5A,$4A,$3A,$4A,$5A,$FF
	db $FF,$6A,$5A,$4A,$3A,$4A,$5A,$FF
	db $FF,$6A,$5A,$4A,$4F,$5F,$6F,$FF
	db $FF,$6F,$4F,$3F,$4F,$5F,$6F,$FF
	db $FF,$6F,$4F,$3F,$4F,$5F,$6F,$FF
	db $FF,$6F,$4F,$3F,$4F,$5F,$6F,$FF
	db 0,0,0,0,0,0,0,0
colors4
	db 0,0,0,0,0,0,0,0        
	db $FF,$71,$6E,$5E,$4E,$5E,$6E,$FF
	db $FF,$71,$6E,$5E,$4E,$5E,$6E,$FF
	db $FF,$71,$6E,$5E,$4E,$5E,$6E,$FF
	db $FF,$71,$6E,$5E,$46,$56,$66,$FF
	db $FF,$71,$66,$56,$46,$56,$66,$FF
	db $FF,$71,$66,$56,$46,$56,$66,$FF
	db $FF,$71,$66,$56,$46,$56,$66,$FF
	db 0,0,0,0,0,0,0,0
colors5
	db 0,0,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0
	db $FF,$71,$6B,$5B,$4B,$5B,$6B,$FF
	db $FF,$71,$6B,$5B,$4B,$5B,$6B,$FF
	db $FF,$71,$6B,$5B,$44,$54,$64,$FF
	db $FF,$71,$64,$54,$44,$54,$64,$FF
	db $FF,$71,$64,$54,$44,$54,$64,$FF
	db 0,$71,0,0,0,0,0,0
	db 0,0,0,0,0,0,0,0
	
	include "square.asm"
	
	include "line.asm"
	
	include "plasma.asm"
	
	include "!player.asm"
	include "!player_data.asm"
	include "music.asm"

	align $0800
chars	; 128*32 h none
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $00,$00,$00,$00,$0F,$1F,$3F,$7F
	db $00,$00,$00,$00,$FF,$FF,$FF,$FF
	db $00,$00,$00,$00,$E0,$E0,$90,$90
	db $F0,$F0,$F0,$F0,$F0,$F0,$F0,$F0
	db $F0,$F0,$F0,$F0,$E0,$C0,$80,$00
	db $50,$50,$50,$50,$6F,$6F,$BF,$BF
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $AA,$AA,$AA,$AA,$AA,$AA,$AA,$AA
	db $55,$55,$55,$55,$55,$55,$55,$55
	db $C0,$80,$00,$00,$00,$00,$00,$00
	db $03,$01,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$80,$C0
	db $00,$00,$00,$00,$00,$00,$01,$03
	db $0F,$0F,$0F,$0F,$0F,$0F,$00,$00

	db $00,$00,$00,$00,$00,$00,$06,$0F
	db $00,$00,$00,$00,$00,$00,$60,$F0
	db $00,$00,$00,$00,$01,$01,$03,$03
	db $00,$00,$3C,$FF,$FF,$FF,$FF,$FF
	db $00,$00,$00,$00,$80,$80,$C0,$C0
	db $03,$03,$03,$03,$03,$03,$03,$03
	db $C0,$C0,$C0,$C0,$C0,$C0,$C0,$C0
	db $01,$01,$00,$00,$00,$00,$00,$00
	db $FF,$FF,$FF,$3C,$00,$00,$00,$00
	db $80,$80,$00,$00,$00,$00,$00,$00
	db $1E,$3F,$3F,$3F,$3F,$1E,$00,$00
	db $00,$00,$00,$00,$00,$01,$01,$05
	db $00,$05,$15,$55,$55,$55,$56,$5B
	db $55,$55,$55,$55,$55,$AA,$FF,$FF
	db $00,$50,$54,$55,$55,$55,$95,$E5
	db $00,$00,$00,$00,$00,$40,$40,$50

	db $05,$05,$15,$15,$15,$16,$16,$57
	db $6F,$7F,$BF,$FF,$FF,$FF,$FF,$FF
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $F9,$FD,$FE,$FF,$FF,$FF,$FF,$FF
	db $50,$50,$54,$54,$54,$94,$94,$D5
	db $57,$5B,$5B,$5B,$5B,$5B,$5B,$57
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $D5,$E5,$E5,$E5,$E5,$E5,$E5,$D5
	db $57,$16,$16,$15,$15,$15,$05,$05
	db $FF,$FF,$FF,$FF,$FF,$BF,$7F,$6F
	db $FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF
	db $FF,$FF,$FF,$FF,$FF,$FE,$FD,$F9
	db $D5,$94,$94,$54,$54,$54,$50,$50
	db $05,$01,$01,$00,$00,$00,$00,$00

	db $5B,$56,$55,$55,$55,$15,$05,$00
	db $FF,$FF,$AA,$55,$55,$55,$55,$55
	db $E5,$95,$55,$55,$55,$54,$50,$00
	db $50,$40,$40,$00,$00,$00,$00,$00
	db $FE,$FE,$FE,$38,$38,$38,$38,$00
	db $EE,$EE,$FE,$FE,$FE,$EE,$EE,$00
	db $FE,$FE,$F8,$FE,$F8,$FE,$FE,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
	db $00,$00,$00,$00,$00,$00,$00,$00
;eof